Class: ActiveScaffold::DataStructures::Sorting

Inherits:
Object
  • Object
show all
Includes:
Enumerable
Defined in:
lib/active_scaffold/data_structures/sorting.rb

Overview

encapsulates the column sorting configuration for the List view

Constant Summary collapse

SORTING_STAGES =
Hash[%w(reset ASC DESC reset).each_cons(2).map{|a|a}].freeze
DEFAULT_SORTING_STAGES =
Hash[%w(ASC DESC ASC).each_cons(2).map{|a|a}].freeze

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(columns) ⇒ Sorting



8
9
10
11
12
# File 'lib/active_scaffold/data_structures/sorting.rb', line 8

def initialize(columns)
  @columns = columns
  @clauses = []
  @constraint_columns = []
end

Instance Attribute Details

#constraint_columnsObject

Returns the value of attribute constraint_columns.



6
7
8
# File 'lib/active_scaffold/data_structures/sorting.rb', line 6

def constraint_columns
  @constraint_columns
end

Instance Method Details

#<<(arg) ⇒ Object

an alias for add. must accept its arguments in a slightly different form, though.



47
48
49
# File 'lib/active_scaffold/data_structures/sorting.rb', line 47

def <<(arg)
  add(*arg)
end

#add(column_name, direction = nil) ⇒ Object

add a clause to the sorting, assuming the column is sortable

Raises:

  • (ArgumentError)


36
37
38
39
40
41
42
43
44
# File 'lib/active_scaffold/data_structures/sorting.rb', line 36

def add(column_name, direction = nil)
  direction ||= 'ASC'
  direction = direction.to_s.upcase
  column = get_column(column_name)
  raise ArgumentError, "Could not find column #{column_name}" if column.nil?
  raise ArgumentError, "Sorting direction unknown" unless [:ASC, :DESC].include? direction.to_sym
  @clauses << [column, direction.untaint] if column.sortable?
  raise ArgumentError, "Can't mix :method- and :sql-based sorting" if mixed_sorting?
end

#clauseObject

builds an order-by clause



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/active_scaffold/data_structures/sorting.rb', line 101

def clause
  return nil if sorts_by_method? || default_sorting?

  # unless the sorting is by method, create the sql string
  order = []
  each do |sort_column, sort_direction|
    next if constraint_columns.include? sort_column.name
    sql = sort_column.sort[:sql]
    next if sql.nil? or sql.empty?

    order << Array(sql).map {|column| "#{column} #{sort_direction}"}.join(', ')
  end

  order << @sorting_by_primary_key if @sorting_by_primary_key # mandatory for postgres
  order unless order.empty?
end

#clearObject

clears the sorting



58
59
60
61
# File 'lib/active_scaffold/data_structures/sorting.rb', line 58

def clear
  @default_sorting = false
  @clauses = []
end

#direction_of(column) ⇒ Object



68
69
70
71
72
# File 'lib/active_scaffold/data_structures/sorting.rb', line 68

def direction_of(column)
  clause = get_clause(column)
  return if clause.nil?
  clause[1]
end

#eachObject

iterate over the clauses



91
92
93
# File 'lib/active_scaffold/data_structures/sorting.rb', line 91

def each
  @clauses.each { |clause| yield clause }
end

#firstObject

provides quick access to the first (and sometimes only) clause



96
97
98
# File 'lib/active_scaffold/data_structures/sorting.rb', line 96

def first
  @clauses.first
end

#next_sorting_of(column, sorted_by_default) ⇒ Object



76
77
78
79
# File 'lib/active_scaffold/data_structures/sorting.rb', line 76

def next_sorting_of(column, sorted_by_default)
  stages = sorted_by_default ? DEFAULT_SORTING_STAGES : SORTING_STAGES
  stages[direction_of(column)] || 'ASC'
end

#set(*args) ⇒ Object

clears the sorting before setting to the given column/direction



52
53
54
55
# File 'lib/active_scaffold/data_structures/sorting.rb', line 52

def set(*args)
  clear
  add(*args)
end

#set_default_sorting(model) ⇒ Object



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
# File 'lib/active_scaffold/data_structures/sorting.rb', line 14

def set_default_sorting(model)
  model_scope = model.send(:build_default_scope)
  order_clause = model_scope.order_values.join(",") if model_scope

  # fallback to setting primary key ordering
  if model.column_names.include?(model.primary_key)
    set(model.primary_key, 'ASC')
    @sorting_by_primary_key = clause
  end
  # If an ORDER BY clause is found set default sorting according to it
  if order_clause
    set_sorting_from_order_clause(order_clause, model.table_name)
    @default_sorting = true
  end
end

#set_nested_sorting(table_name, order_clause) ⇒ Object



30
31
32
33
# File 'lib/active_scaffold/data_structures/sorting.rb', line 30

def set_nested_sorting(table_name, order_clause)
  clear
  set_sorting_from_order_clause(order_clause, table_name)
end

#sorts_by_method?Boolean

checks whether any column is configured to sort by method (using a proc)



82
83
84
# File 'lib/active_scaffold/data_structures/sorting.rb', line 82

def sorts_by_method?
  @clauses.any? { |sorting| sorting[0].sort.is_a? Hash and sorting[0].sort.has_key? :method }
end

#sorts_by_sql?Boolean



86
87
88
# File 'lib/active_scaffold/data_structures/sorting.rb', line 86

def sorts_by_sql?
  @clauses.any? { |sorting| sorting[0].sort.is_a? Hash and sorting[0].sort.has_key? :sql }
end

#sorts_on?(column) ⇒ Boolean

checks whether the given column (a Column object or a column name) is in the sorting



64
65
66
# File 'lib/active_scaffold/data_structures/sorting.rb', line 64

def sorts_on?(column)
  !get_clause(column).nil?
end