Class: ActiveScaffold::DataStructures::Sorting

Inherits:
Object
  • Object
show all
Includes:
Enumerable
Defined in:
lib/active_scaffold/data_structures/sorting.rb

Overview

encapsulates the column sorting configuration for the List view

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(columns) ⇒ Sorting

Returns a new instance of Sorting.



8
9
10
11
12
# File 'lib/active_scaffold/data_structures/sorting.rb', line 8

def initialize(columns)
  @columns = columns
  @clauses = []
  @constraint_columns = []
end

Instance Attribute Details

#constraint_columnsObject

Returns the value of attribute constraint_columns.



6
7
8
# File 'lib/active_scaffold/data_structures/sorting.rb', line 6

def constraint_columns
  @constraint_columns
end

Instance Method Details

#<<(arg) ⇒ Object

an alias for add. must accept its arguments in a slightly different form, though.



45
46
47
# File 'lib/active_scaffold/data_structures/sorting.rb', line 45

def <<(arg)
  add(*arg)
end

#add(column_name, direction = nil) ⇒ Object

add a clause to the sorting, assuming the column is sortable

Raises:

  • (ArgumentError)


34
35
36
37
38
39
40
41
42
# File 'lib/active_scaffold/data_structures/sorting.rb', line 34

def add(column_name, direction = nil)
  direction ||= 'ASC'
  direction = direction.to_s.upcase
  column = get_column(column_name)
  raise ArgumentError, "Could not find column #{column_name}" if column.nil?
  raise ArgumentError, "Sorting direction unknown" unless [:ASC, :DESC].include? direction.to_sym
  @clauses << [column, direction.untaint] if column.sortable?
  raise ArgumentError, "Can't mix :method- and :sql-based sorting" if mixed_sorting?
end

#clauseObject

builds an order-by clause



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/active_scaffold/data_structures/sorting.rb', line 92

def clause
  return nil if sorts_by_method? || default_sorting?

  # unless the sorting is by method, create the sql string
  order = []
  each do |sort_column, sort_direction|
    next if constraint_columns.include? sort_column.name
    sql = sort_column.sort[:sql]
    next if sql.nil? or sql.empty?

    order << Array(sql).map {|column| "#{column} #{sort_direction}"}.join(', ')
  end

  order unless order.empty?
end

#clearObject

clears the sorting



56
57
58
59
# File 'lib/active_scaffold/data_structures/sorting.rb', line 56

def clear
  @default_sorting = false
  @clauses = []
end

#direction_of(column) ⇒ Object



66
67
68
69
70
# File 'lib/active_scaffold/data_structures/sorting.rb', line 66

def direction_of(column)
  clause = get_clause(column)
  return if clause.nil?
  clause[1]
end

#eachObject

iterate over the clauses



82
83
84
# File 'lib/active_scaffold/data_structures/sorting.rb', line 82

def each
  @clauses.each { |clause| yield clause }
end

#firstObject

provides quick access to the first (and sometimes only) clause



87
88
89
# File 'lib/active_scaffold/data_structures/sorting.rb', line 87

def first
  @clauses.first
end

#set(*args) ⇒ Object

clears the sorting before setting to the given column/direction



50
51
52
53
# File 'lib/active_scaffold/data_structures/sorting.rb', line 50

def set(*args)
  clear
  add(*args)
end

#set_default_sorting(model) ⇒ Object



14
15
16
17
18
19
20
21
22
23
24
25
26
# File 'lib/active_scaffold/data_structures/sorting.rb', line 14

def set_default_sorting(model)
  model_scope = model.send(:build_default_scope)
  order_clause = model_scope.arel.order_clauses.join(",") if model_scope

  # If an ORDER BY clause is found set default sorting according to it, else
  # fallback to setting primary key ordering
  if order_clause
    set_sorting_from_order_clause(order_clause, model.table_name)
    @default_sorting = true
  else
    set(model.primary_key, 'ASC') if model.column_names.include?(model.primary_key)
  end
end

#set_nested_sorting(table_name, order_clause) ⇒ Object



28
29
30
31
# File 'lib/active_scaffold/data_structures/sorting.rb', line 28

def set_nested_sorting(table_name, order_clause)
  clear
  set_sorting_from_order_clause(order_clause, table_name)
end

#sorts_by_method?Boolean

checks whether any column is configured to sort by method (using a proc)

Returns:

  • (Boolean)


73
74
75
# File 'lib/active_scaffold/data_structures/sorting.rb', line 73

def sorts_by_method?
  @clauses.any? { |sorting| sorting[0].sort.is_a? Hash and sorting[0].sort.has_key? :method }
end

#sorts_by_sql?Boolean

Returns:

  • (Boolean)


77
78
79
# File 'lib/active_scaffold/data_structures/sorting.rb', line 77

def sorts_by_sql?
  @clauses.any? { |sorting| sorting[0].sort.is_a? Hash and sorting[0].sort.has_key? :sql }
end

#sorts_on?(column) ⇒ Boolean

checks whether the given column (a Column object or a column name) is in the sorting

Returns:

  • (Boolean)


62
63
64
# File 'lib/active_scaffold/data_structures/sorting.rb', line 62

def sorts_on?(column)
  !get_clause(column).nil?
end